@@ -16,11 +16,11 @@
 #include <DCommandLinkButton>
 #include <DDialogCloseButton>
 #include <DApplicationHelper>
+#include <DPaletteHelper>
 #include <DGuiApplicationHelper>
 #include <DWidgetUtil>
 #include <DLog>
 #include <DFontSizeManager>
-#include <DVerticalLine>
 
 #include <QGridLayout>
 #include <QHBoxLayout>
@@ -135,17 +135,19 @@ void CustomCommandOptDlg::initUI()
     addContent(contentFrame);
     //判断是添加操作窗口还是修改操作窗口
     if (CCT_ADD == m_type) {
-        setFixedSize(m_iFixedWidth, m_iFixedHeightAddSize);
         setTitle(tr("Add Command"));
         initCommandFromClipBoardText();
 
+#ifdef DTKWIDGET_CLASS_DSizeMode
+        getMainLayout()->addSpacing(m_iSpaceSizeSeven);
+#else
         getMainLayout()->addSpacing(m_iSpaceSizeEighteen);
+#endif
     } else {
-        setFixedSize(m_iFixedWidth, m_iFixedHeightEditSize);
         setTitle(tr("Edit Command"));
 
-        QWidget *deleteCmdWidget = new QWidget(this);
-        deleteCmdWidget->setFixedHeight(m_iFixedHeight);
+        m_deleteCmdWidget = new QWidget(this);
+        m_deleteCmdWidget->setFixedHeight(m_iFixedHeight);
 
         QHBoxLayout *deleteCmdLayout = new QHBoxLayout();
         deleteCmdLayout->setSpacing(m_iSpaceSizeZero);
@@ -157,9 +159,9 @@ void CustomCommandOptDlg::initUI()
         deleteCmdLayout->addStretch();
         deleteCmdLayout->addWidget(deleteCmdBtn);
         deleteCmdLayout->addStretch();
-        deleteCmdWidget->setLayout(deleteCmdLayout);
+        m_deleteCmdWidget->setLayout(deleteCmdLayout);
 
-        getMainLayout()->addWidget(deleteCmdWidget);
+        getMainLayout()->addWidget(m_deleteCmdWidget);
 
         connect(deleteCmdBtn, &DCommandLinkButton::clicked, this, &CustomCommandOptDlg::slotDelCurCustomCommand);
 
@@ -182,6 +184,27 @@ void CustomCommandOptDlg::initUI()
     m_lastCmdShortcut = m_shortCutLineEdit->keySequence().toString();
     connect(this, &CustomCommandOptDlg::confirmBtnClicked, this, &CustomCommandOptDlg::slotAddSaveButtonClicked);
     connect(m_shortCutLineEdit, &KeySequenceEdit::editingFinished, this, &CustomCommandOptDlg::slotShortCutLineEditingFinished);
+
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    updateSizeMode();
+    connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::sizeModeChanged, this, &CustomCommandOptDlg::updateSizeMode);
+    // 字体变更时更新布局
+    connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::fontChanged, this, [this](){
+        if (isVisible() && layout()) {
+            layout()->invalidate();
+            updateGeometry();
+            // 根据新界面布局，刷新界面大小
+            QTimer::singleShot(0, this, [=](){ resize(SETTING_DIALOG_WIDTH, minimumSizeHint().height()); });
+        }
+    });
+
+#else
+    if (CCT_ADD == m_type) {
+        setFixedSize(m_iFixedWidth, m_iFixedHeightAddSize);
+    } else {
+        setFixedSize(m_iFixedWidth, m_iFixedHeightEditSize);
+    }
+#endif
 }
 
 inline void CustomCommandOptDlg::slotNameLineEditingFinished()
@@ -237,7 +260,7 @@ inline void CustomCommandOptDlg::slotShortCutLineEditingFinished(const QKeySeque
 void CustomCommandOptDlg::initUITitle()
 {
     QVBoxLayout *mainLayout = new QVBoxLayout();
-    mainLayout->setSpacing(0);
+    mainLayout->setSpacing(SPACEHEIGHT);
     mainLayout->setContentsMargins(0, 0, 0, 10);
 
     QHBoxLayout *titleLayout = new QHBoxLayout();
@@ -269,7 +292,7 @@ void CustomCommandOptDlg::initUITitle()
     // 字色
     DPalette palette = m_titleText->palette();
     QColor color;
-    if (DApplicationHelper::DarkType == DApplicationHelper::instance()->themeType())
+    if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType())
         color = QColor::fromRgb(192, 198, 212, 255);
     else
         color = QColor::fromRgb(0, 26, 46, 255);
@@ -303,7 +326,7 @@ void CustomCommandOptDlg::initTitleConnections()
 {
     connect(m_closeButton, &DWindowCloseButton::clicked, this, &CustomCommandOptDlg::slotCloseButtonClicked);
     // 字体颜色随主题变化变化
-    connect(DApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &CustomCommandOptDlg::slotThemeTypeChanged);
+    connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &CustomCommandOptDlg::slotThemeTypeChanged);
 }
 
 inline void CustomCommandOptDlg::slotCloseButtonClicked()
@@ -315,7 +338,7 @@ inline void CustomCommandOptDlg::slotThemeTypeChanged(DGuiApplicationHelper::Col
 {
     DPalette palette = m_titleText->palette();
     QColor color;
-    if (DApplicationHelper::DarkType == themeType)
+    if (DGuiApplicationHelper::DarkType == themeType)
         color = QColor::fromRgb(192, 198, 212, 255);
     else
         color = QColor::fromRgb(0, 26, 46, 255);
@@ -474,14 +497,12 @@ void CustomCommandOptDlg::addCancelConfirmButtons()
     m_cancelBtn = new DPushButton(this);
     m_cancelBtn->setObjectName("CustomCancelButton");//Add by ut001000 renfeixiang 2020-08-13
     m_cancelBtn->setFixedWidth(209);
-    m_cancelBtn->setFixedHeight(36);
     m_cancelBtn->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
     m_cancelBtn->setFont(btnFont);
 
     m_confirmBtn = new DSuggestButton(this);
     m_confirmBtn->setObjectName("CustomConfirmButton");//Add by ut001000 renfeixiang 2020-08-13
     m_confirmBtn->setFixedWidth(209);
-    m_confirmBtn->setFixedHeight(36);
     m_confirmBtn->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
     m_confirmBtn->setFont(btnFont);
 
@@ -490,17 +511,17 @@ void CustomCommandOptDlg::addCancelConfirmButtons()
 
     setTabOrder(m_confirmBtn, m_closeButton);//设置右上角关闭按钮的tab键控制顺序
 
-    DVerticalLine *verticalLine = new DVerticalLine(this);
-    DPalette pa = DApplicationHelper::instance()->palette(verticalLine);
+    m_verticalLine = new DVerticalLine(this);
+    DPalette pa = DApplicationHelper::instance()->palette(m_verticalLine);
     QColor splitColor = pa.color(DPalette::ItemBackground);
     pa.setBrush(DPalette::Background, splitColor);
-    verticalLine->setPalette(pa);
-    verticalLine->setBackgroundRole(QPalette::Background);
-    verticalLine->setAutoFillBackground(true);
-    verticalLine->setFixedSize(3, 28);
+    m_verticalLine->setPalette(pa);
+    m_verticalLine->setBackgroundRole(QPalette::Background);
+    m_verticalLine->setAutoFillBackground(true);
+    m_verticalLine->setFixedSize(3, 28);
 
     buttonsLayout->addWidget(m_cancelBtn);
-    buttonsLayout->addWidget(verticalLine);
+    buttonsLayout->addWidget(m_verticalLine);
     buttonsLayout->addWidget(m_confirmBtn);
     /************************ Add by m000743 sunchengxi 2020-04-15:默认enter回车按下，走确认校验流程 Begin************************/
     m_confirmBtn->setDefault(true);
@@ -620,6 +641,42 @@ inline void CustomCommandOptDlg::slotSetShortCutLineEditFocus()
     m_shortCutLineEdit->setFocus();
 }
 
+/**
+ * @brief 接收 DGuiApplicationHelper::sizeModeChanged() 信号, 根据不同的布局模式调整
+ *      当前界面的布局. 只能在界面创建完成后调用.
+ */
+void CustomCommandOptDlg::updateSizeMode()
+{
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    if (DGuiApplicationHelper::isCompactMode()) {
+        m_titleBar->setFixedHeight(WIN_TITLE_BAR_HEIGHT_COMPACT);
+        m_logoIcon->setFixedSize(QSize(ICONSIZE_40_COMPACT, ICONSIZE_40_COMPACT));
+        m_closeButton->setIconSize(QSize(ICONSIZE_40_COMPACT, ICONSIZE_40_COMPACT));
+        m_verticalLine->setFixedSize(VERTICAL_WIDTH_COMPACT, VERTICAL_HEIGHT_COMPACT);
+        if (m_deleteCmdWidget) {
+            m_deleteCmdWidget->setFixedHeight(m_iFixedHeightCompact);
+        }
+
+    } else {
+        m_titleBar->setFixedHeight(WIN_TITLE_BAR_HEIGHT);
+        m_logoIcon->setFixedSize(QSize(ICONSIZE_50, ICONSIZE_50));
+        m_closeButton->setIconSize(QSize(ICONSIZE_50, ICONSIZE_50));
+        m_verticalLine->setFixedSize(VERTICAL_WIDTH, VERTICAL_HEIGHT);
+        if (m_deleteCmdWidget) {
+            m_deleteCmdWidget->setFixedHeight(m_iFixedHeight);
+        }
+    }
+
+    if (layout()) {
+        layout()->invalidate();
+    }
+
+    updateGeometry();
+    // 根据新界面布局，刷新界面大小
+    QTimer::singleShot(0, this, [=](){ resize(SETTING_DIALOG_WIDTH, minimumSizeHint().height()); });
+#endif
+}
+
 void CustomCommandOptDlg::addContent(QWidget *content)
 {
     Q_ASSERT(nullptr != m_contentLayout);
