@@ -288,7 +288,7 @@ void Settings::initConnection()
 {
     connect(settings, &Dtk::Core::DSettings::valueChanged, this, [ = ](const QString & key, const QVariant & value) {
         Q_UNUSED(value)
-        if (key.contains("basic.interface.") || key.contains("advanced.cursor.") || key.contains("advanced.scroll.") || key.contains("advanced.shell."))
+        if (key.contains("basic.interface.") || key.contains("advanced.cursor.") || key.contains("advanced.scroll.") || key.contains("advanced.shell.") || key.contains("advanced.debuginfod."))
             emit terminalSettingChanged(key);
         else if (key.contains("shortcuts."))
             emit shortcutSettingChanged(key);
@@ -608,6 +608,16 @@ bool Settings::disableControlFlow(void)
     return settings->option("advanced.shell.disable_ctrl_flow")->value().toBool();
 }
 
+bool Settings::enableDebuginfod()
+{
+    return settings->option("advanced.debuginfod.enable_debuginfod")->value().toBool();
+}
+
+QString Settings::debuginfodUrls()
+{
+    return settings->option("advanced.debuginfod.debuginfod_urls")->value().toString();
+}
+
 /******** Add by ut001000 renfeixiang 2020-06-15:增加 每次显示设置界面时，更新设置的等宽字体 End***************/
 
 /*******************************************************************************
